/* 
 * Blinky - a GTK network usage monitor
 *
 * Copyright (C) 2002, Benjamin Miller <bmiller@users.sf.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <gtk/gtk.h>
#include "blinky.h"


static GtkWidget *acsel, *icsel, *dcsel; /* color selection dialogs */


void
show_colorsel (GtkWidget *w, int which)
{
    GtkWidget *colorsel;
    gdouble color[3];
    GdkColor *gcol;

    switch (which) {
    case 1: /* AC */
	if (acsel)
	    return;
	acsel = gtk_color_selection_dialog_new ("Select Active Color");
	colorsel = acsel;
	gcol = options->ac;
	break;
    case 2: /* IC */
	if (icsel)
	    return;
	icsel = gtk_color_selection_dialog_new ("Select Inactive Color");
	colorsel = icsel;
	gcol = options->ic;
	break;
    case 3: /* DC */
	if (dcsel)
	    return;
	dcsel = gtk_color_selection_dialog_new ("Select Down Color");
	colorsel = dcsel;
	gcol = options->dc;
	break;
    default:
	return;
    }

    color[0] = (gdouble)(gcol->red) / 0xFFFF;
    color[1] = (gdouble)(gcol->green) / 0xFFFF;
    color[2] = (gdouble)(gcol->blue) / 0xFFFF;
    gtk_color_selection_set_color(GTK_COLOR_SELECTION
				  (GTK_COLOR_SELECTION_DIALOG(colorsel)->colorsel), color);
    gtk_signal_connect (GTK_OBJECT(colorsel), "delete_event",
			GTK_SIGNAL_FUNC(delete_colorsel), (void *)which);
    gtk_signal_connect (GTK_OBJECT(GTK_COLOR_SELECTION_DIALOG(colorsel)
				   ->cancel_button), "clicked",
			GTK_SIGNAL_FUNC(delete_colorsel), (void *)which);
    gtk_signal_connect (GTK_OBJECT(GTK_COLOR_SELECTION_DIALOG(colorsel)
				   ->ok_button), "clicked",
			GTK_SIGNAL_FUNC(apply_colorsel), (void *)which);
    gtk_widget_show (colorsel);
}


void
apply_colorsel (GtkWidget *w, int which)
{
    gdouble color[3];
    GtkWidget *colorsel;
    GdkColor *gcol;

    switch (which) {
    case 1: /* AC */
	if (!acsel)
	    return;
	colorsel = acsel;
	gcol = options->ac;
	gdk_gc_destroy (options->agc);
	options->agc = NULL;
	break;
    case 2: /* IC */
	if (!icsel)
	    return;
	colorsel = icsel;
	gcol = options->ic;
	gdk_gc_destroy (options->igc);
	options->igc = NULL;
	break;
    case 3: /* DC */
	if (!dcsel)
	    return;
	colorsel = dcsel;
	gcol = options->dc;
	gdk_gc_destroy (options->dgc);
	options->dgc = NULL;
	break;
    default:
	return;
    }

    /* Set the color */
    gtk_color_selection_get_color(GTK_COLOR_SELECTION
				  (GTK_COLOR_SELECTION_DIALOG(colorsel)->colorsel), color);
    gcol->red = color[0] * 0xFFFF;
    gcol->green = color[1] * 0xFFFF;
    gcol->blue = color[2] * 0xFFFF;

    /* Destroy the dialog */
    delete_colorsel (w, which);
}


void
delete_colorsel (GtkWidget *w, int which)
{
    switch (which) {
    case 1: /* AC */
	gtk_widget_destroy(acsel);
	acsel = NULL;
	break;
    case 2: /* IC */
	gtk_widget_destroy(icsel);
	icsel = NULL;
	break;
    case 3: /* DC */
	gtk_widget_destroy(dcsel);
	dcsel = NULL;
	break;
    default:
	gtk_widget_destroy(w);
	break;
    }
}


/*
 * Local variables:
 * c-basic-offset: 4
 * End:
 */
